package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(``P`!````$*8$"#0```!`H@```````#0`(``,
M`"@`'0`<``8````T````-(`$"#2`!`B``0``@`$```0````$`````P```+0!
M``"T@00(M($$"!,````3````!`````$````!``````````"`!`@`@`0(\!``
M`/`0```$`````!````$`````(````*`$"`"@!`B,+P``C"\```4`````$```
M`0````!0````T`0(`-`$"/Q$``#\1```!``````0```!````R)X``,@N!0C(
M+@4(/`(``*P2```&`````!````(```#DG@``Y"X%".0N!0@(`0``"`$```8`
M```$````!````,@!``#(@00(R($$"&P```!L````!`````0```!3Y71D[`$`
M`.R!!`CL@00(*````"@````$````!````%#E=&0PCP``,`\%"#`/!0C4````
MU`````0````$````4>5T9```````````````````````````!@```!````!2
MY71DR)X``,@N!0C(+@4(.`$``#@!```$`````0```"]L:6(O;&0M;&EN=7@N
M<V\N,@``!````!0````#````1TY5`/J1&8<ADF=;S:78X3^S35K&#6_R!```
M`!@````%````1TY5``$``<`$`````0````(``<`$`````0````0````0````
M`0```$=.50```````P````(`````````$0```#T````(````"``````<``0E
M0`2"*`$``:"&`8C``0`"2R@$*#B",D.*``0(/0```#X```!!````1````$4`
M``!,````3@```%````!3````5`````````!5````6````%D```!:````````
M``````![\$IK;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP,+E/RRZXY)\\MO3'?NA;&!J"4/6A_F<@6:OS&;%N9Q`./*+'$)%U>R)
M!W#3R=6R<3-BV^T,.I<+6.CM[*?=HVM_J9R;X:<""@J*$%>CX/M)````````
M`````````````+$"`````````````!(````K`@`````````````2````)0(`
M````````````$@```,X``````````````!(```!@```````````````2````
M%P(`````````````$@```%4!`````````````!(```#4`0`````````````2
M````40(`````````````$@````$``````````````"`````[`@``````````
M```2````AP(`````````````$@```-0"`````````````!(````5`0``````
M```````2````@0``````````````$@````4!`````````````!(```#W````
M```````````2`````P(`````````````$@```/X!`````````````!(```!S
M`0`````````````2````TP``````````````$@```*,"`````````````!(`
M``!@`@`````````````2````E`(`````````````$@```!``````````````
M`!(````M```````````````6````O0``````````````$@```%$`````````
M`````!(```"Z`0`````````````2````\0$`````````````$@```-L!````
M`````````!(```"7`P`````````````2````H0``````````````$@```)P"
M`````````````!(````W`0`````````````2````RP$`````````````$@``
M`(X"`````````````!(````I`0`````````````2````$`(`````````````
M$@```&P!`````````````!(```#8```````````````2````G`$`````````
M````$@```/@!`````````````!(```#J`0`````````````2````7P(`````
M````````$@```#("`````````````!(```#B`0`````````````2````;```
M````````````$@```&`!`````````````!(```!#`@`````````````2````
M@`(`````````````$@```,("`````````````!(````>`0`````````````2
M````'@``````````````$@```,0!`````````````!(```!G`@``````````
M```2````L@$`````````````$@```*H"`````````````!(```"M`0``````
M```````2````CP``````````````$@```$4!``#0H00(`````!(```"@`P``
M1LX$".T````2``X`T@,``/6_!`@]"P``$@`.`'0"```0I`0(_0$``!(`#@`:
M`P``B[@$"`4````2``X`/P,``#++!`@4`P``$@`.`/@#``"0N`0(Q@$``!(`
M#@#!`P``!#$%"``````0`!H`*P,``%:Z!`@@````$@`.`%4#``"9O@0(7```
M`!(`#@"-`0``!-`$"`0````1`!``N0,``(VW!`@O````$@`.`,T#``!T004(
M`````!``&@!^`0``T"X%"!,````1`!4`Y@,```^_!`CF````$@`.`*P#``#T
M,`4(`````!``&0!`````X*$$"``````2````>0,``':Z!`C`````$@`.`,H"
M```P,04(!````!$`&@!Y`@``(#$%"`0````1`!H`WP,```0Q!0@`````$``9
M``4$````,04(!````!$`&0#D````T*`$"``````2````L@,``!"F!`@Z````
M$@`.`*X#``#T,`4(`````"``&0`X`P```-`$"`0````1`!``S`(``#`Q!0@$
M````(0`:`(4#``#UO@0(&@```!(`#@!C`P``O+<$",\````2``X`L````$`Q
M!0@!````$0`:``\$```VNP0(8P,``!(`#@``7U]G;6]N7W-T87)T7U\`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`
M4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!097)L7V%V7W-H:69T`%!E<FQ?<W9?,G!V
M7V9L86=S`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA
M3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL
M;V,`4$Q?;65M;W)Y7W=R87``7TE/7W-T9&EN7W5S960`7U]S=&%C:U]C:&M?
M9F%I;`!E>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O
M<&5N-C0`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D
M`%]?;65M8W!Y7V-H:P!S=')S='(`7U]S=')N8W!Y7V-H:P!M:V1I<@!G971P
M:60`<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C
M:&L`;'-T870V-`!?7VQI8F-?<W1A<G1?;6%I;@!S=&1E<G(`;65M8VAR`'-T
M<F-H<@!C;&]S90!O<&5N9&ER`&=E='5I9`!A8V-E<W,`<W1R8VUP`%]?97)R
M;F]?;&]C871I;VX`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O
M<FL`;&EB<&5R;"YS;RXU+C,X+C``;&EB;2YS;RXV`&QI8F,N<V\N-@!L:6)C
M<GEP="YS;RXR`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]F<%]H
M=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R;VU?
M9V5T<'=U:60`<&%R7V-L96%N=7``7U]D871A7W-T87)T`'AS7VEN:70`7U]B
M<W-?<W1A<G0`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L
M:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7VEN:71?96YV`$=,
M24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"0U\R+C,S`$=,24)#
M7S(N,RXR`$=,24)#7S(N,0!'3$E"0U\R+C,N-`!'3$E"0U\R+C``+W5S<B]L
M:6(O<&5R;#4O-2XS."XP+VDV.#8M<&QD+6QI;G5X+71H<F5A9"UM=6QT:2]#
M3U)%``````(``@`"``$``0`#``$`!``#``$``@`"``4``0`!``$``0`#``(`
M`0`"``(`!@`"``$``0`!``$`!P`"``(``@`!``(``0`"``(``0`"``(``0`(
M``(``@`&``(``@`!``$``P`"``(``0`!``(`"0`$``(``@`!``$``0`!``$`
M`0`!``$``0`!``$``0`!``$``0`!``$``0`!``(``@`!``$``0`!``$``0`"
M``$``0`!``$````!``@``@,``!``````````M)&6!@``"0`<!```$````!1I
M:0T```@`)P0``!`````2:6D-```'`#$$```0````LY&6!@``!@`[!```$```
M`'(9:0D```4`1@0``!`````1:6D-```$`%($```0````=!EI"0```P!<!```
M$````!!I:0T```(`:`0```````#L+P4(!@H``/`O!0@.&@``T"X%"`5*```@
M,04(!5```#`Q!0@%3P``0#$%"`5:````,`4(!P$```0P!0@'`@``"#`%"`<#
M```,,`4(!P0``!`P!0@'!0``%#`%"`<&```8,`4(!P<``!PP!0@'"```(#`%
M"`<)```D,`4(!U,``"@P!0@'"P``+#`%"`<,```P,`4(!PT``#0P!0@'#@``
M.#`%"`</```\,`4(!Q```$`P!0@'$0``1#`%"`<2``!(,`4(!Q,``$PP!0@'
M%```4#`%"`<5``!4,`4(!Q8``%@P!0@'%P``7#`%"`<8``!@,`4(!QD``&0P
M!0@'/0``:#`%"`=-``!L,`4(!QL``'`P!0@''```=#`%"`<=``!X,`4(!QX`
M`'PP!0@''P``@#`%"`<@``"$,`4(!R$``(@P!0@'(@``C#`%"`<C``"0,`4(
M!R0``)0P!0@')0``F#`%"`<F``"<,`4(!R<``*`P!0@'*```I#`%"`<I``"H
M,`4(!RH``*PP!0@'*P``L#`%"`<L``"T,`4(!RT``+@P!0@'+@``O#`%"`<O
M``#`,`4(!S```,0P!0@',0``R#`%"`<R``#,,`4(!S,``-`P!0@'-```U#`%
M"`<U``#8,`4(!S8``-PP!0@'-P``X#`%"`<X``#D,`4(!SD``.@P!0@'.@``
M[#`%"`<[``#P,`4(!SP`````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[[4X/L".A#!@``@</GCP``BX/X____A<!T`O_0@\0(6\,`````````
M``````#_-?@O!0C_)?PO!0@`````_R4`,`4(:`````#IX/____\E!#`%"&@(
M````Z=#_____)0@P!0AH$````.G`_____R4,,`4(:!@```#IL/____\E$#`%
M"&@@````Z:#_____)10P!0AH*````.F0_____R48,`4(:#````#I@/____\E
M'#`%"&@X````Z7#_____)2`P!0AH0````.E@_____R4D,`4(:$@```#I4/__
M__\E*#`%"&A0````Z4#_____)2PP!0AH6````.DP_____R4P,`4(:&````#I
M(/____\E-#`%"&AH````Z1#_____)3@P!0AH<````.D`_____R4\,`4(:'@`
M``#I\/[___\E0#`%"&B`````Z>#^____)40P!0AHB````.G0_O___R5(,`4(
M:)````#IP/[___\E3#`%"&B8````Z;#^____)5`P!0AHH````.F@_O___R54
M,`4(:*@```#ID/[___\E6#`%"&BP````Z8#^____)5PP!0AHN````.EP_O__
M_R5@,`4(:,````#I8/[___\E9#`%"&C(````Z5#^____)6@P!0AHT````.E`
M_O___R5L,`4(:-@```#I,/[___\E<#`%"&C@````Z2#^____)70P!0AHZ```
M`.D0_O___R5X,`4(:/````#I`/[___\E?#`%"&CX````Z?#]____)8`P!0AH
M``$``.G@_?___R6$,`4(:`@!``#IT/W___\EB#`%"&@0`0``Z<#]____)8PP
M!0AH&`$``.FP_?___R60,`4(:"`!``#IH/W___\EE#`%"&@H`0``Z9#]____
M)9@P!0AH,`$``.F`_?___R6<,`4(:#@!``#I</W___\EH#`%"&A``0``Z6#]
M____):0P!0AH2`$``.E0_?___R6H,`4(:%`!``#I0/W___\EK#`%"&A8`0``
MZ3#]____);`P!0AH8`$``.D@_?___R6T,`4(:&@!``#I$/W___\EN#`%"&AP
M`0``Z0#]____);PP!0AH>`$``.GP_/___R7`,`4(:(`!``#IX/S___\EQ#`%
M"&B(`0``Z=#\____)<@P!0AHD`$``.G`_/___R7,,`4(:)@!``#IL/S___\E
MT#`%"&B@`0``Z:#\____)=0P!0AHJ`$``.F0_/___R78,`4(:+`!``#I@/S_
M__\EW#`%"&BX`0``Z7#\____)>`P!0AHP`$``.E@_/___R7D,`4(:,@!``#I
M4/S___\EZ#`%"&C0`0``Z4#\____)>PP!0AHV`$``.DP_/___R7P,`4(:.`!
M``#I(/S__U6)Y5=64X/D\(/L0(M%#(E$)"R+11")1"0H9:$4````B40D/#'`
MC40D*(E$)`B-1"0LB40D!(U%"(D$).A/____QT0D"-"@!`C'1"0$T*`$",<$
M)."A!`CHQBH``(`]0#$%"``/A``!``"A\"\%"&6+`("(H@(```.+10B#P`4]
M____/P^'3@$```'``<")!"3HJO[__XG&HV1!!0B+7"0LBP.)!L=&!,S1!`BA
M`#$%"(E&",=&#,_1!`C'!6A!!0@$````BWT(@_\!?AN-0P2-5A"-##\!R0'+
MBPB)"H/`!(/"!#G#=?+'1+X,`````,=$)!``````B70D#(/'`XE\)`C'1"0$
M*+<$"*%P004(B00DZ'C[__^)PX7`=':A<$$%"(D$).AE_?__C50D.+BGT`0(
MZ.8,``"%P'1KH7!!!0B)!"3H%OO__^AA_/__BT0D/&4K!10````/A9@```")
MV(UE]%M>7UW#Z/'[__^C<$$%"(7`='2)!"3H</S__Z'P+P4(98L0QH)R!0``
M`.G;_O__H7!!!0B)!"3H7_O__XG#Z7;___^A;$$%"(7`=`J)!"3H?2@``.N"
MC50D.+A<T`0(Z%8,``"C;$$%"(7`#X1G____Z]G'1"0$T"X%",<$)%?0!`CH
M1/W__\<$)`$```#HZ/W__^C3_/__9I"0\P\>^S'M7HGA@^3P4%12Z!D```"!
MP]")``!J`&H`45:-@TUV__]0Z(3]___TBQPDP_,/'OOIQOW___,/'OO#D(L<
M),.X!#$%"#T$,04(=!RX`````(7`=!-5B>6#[!C'!"0$,04(_]")[%W#P[@$
M,04(+00Q!0B)PL'Z`L'H'P'0T?AT(+H`````A=)T%U6)Y8/L&(E$)`3'!"0$
M,04(_]*)[%W#PX`]03$%"`!U%E6)Y8/L".B*____Q@5!,04(`8GL7</#ZZ5F
MD&:09I!FD%575E.!['P!``")P8E$)`QEH10```")A"1L`0``,<"+5($<#\J)
M5(0L@\`!@_@0=>Z+="1@BVPD9(M$)&B+7"0LBTPD,(E,)`B-5"0TZP2)3"0(
MBPJ)QXM"&#'(,?`QV-'`B4(X@\($B>Z)_8M<)`B-O"0T`0``.==UU(M\)`R+
M'XMW!(MO"(M/#(M'$(E$)!P#1"0L!9EY@EJ)VL'"!0'0B>HQRB'RB<\QR@'0
MB70D$(GRP<H"B>DQT8G>(=DQZ8E\)!B+7"0P`?N!PYEY@EH!RXG!P<$%`<N)
M="0(P<X"B=$Q\2'!,=&);"04`VPD-(GO@<>9>8):`?F)W<'%!0'IP<@"B?4Q
MQ8GO(=\Q]P-4)#B!PIEY@EH!^HG-P<4%`>K!RP*)Q3'=B>\ASS''`W0D/('&
MF7F"6@'^B=7!Q04![L')`HG=,<V)[R'7,=\#1"1`!9EY@EH!^(GUP<4%`>C!
MR@*)S3'5B>\A]S'/`UPD1('#F7F"6@'[B<7!Q04!Z\'.`HG5,?6)[R'',=<#
M3"1(@<&9>8):`?F)W<'%!0'IP<@"B?4QQ8GO(=\Q]P-4)$R!PIEY@EH!^HG-
MP<4%`>K!RP*)Q3'=B>\ASS''`W0D4('&F7F"6@'^B=7!Q04![L')`HG=,<V)
M[R'7,=\#1"14!9EY@EH!^(GUP<4%`>C!R@*)S3'5B>\A]S'/`UPD6('#F7F"
M6@'[B<7!Q04!Z\'.`HG5,?6)[R'',=<#3"1<@<&9>8):`?F)W<'%!0'IP<@"
MB?4QQ8GO(=\Q]P-4)&"!PIEY@EH!^HG-P<4%`>K!RP*)Q3'=B>\ASS''`W0D
M9('&F7F"6@'^B=7!Q04![L')`HG=,<V)[R'7,=\#1"1H!9EY@EH!^(GUP<4%
M`>C!R@*)S3'5B>\A]S'/`UPD;('#F7F"6@'[B<7!Q04!Z\'.`HG5,?6)[R''
M,=<#3"1P@<&9>8):`?F)W<'%!0'IP<@"B?4QQ8GO(=\Q]P-4)'2!PIEY@EH!
M^HG-P<4%`>K!RP*)Q3'=B>\ASS''`W0D>('&F7F"6@'WB=7!Q04![\')`@-$
M)'P%H>O9;HG=,<V)[C'6`<:)^,'`!0'&P<H"`YPD@````(V#H>O9;HG+,=,Q
M^P'#B?#!P`4!PXGXP<@"`XPDA````(VYH>O9;HG1,<$Q\0'YB=W!Q04!Z<'.
M`@.4)(@```"-NJ'KV6Z)PC'R,=H!^HG-P<4%`>K!RP(#A"2,````C;BAZ]EN
MB?`QV#'(`?B)U<'%!0'HP<D"`[0DD````(V^H>O9;HG=,<V)[C'6`?Z)Q<'%
M!0'NP<H"`YPDE````(V[H>O9;HG+,=,QPP'[B?7!Q04!Z\'(`@.,))@```"-
MN:'KV6Z)T3'!,?$!^8G=P<4%`>G!S@(#E"2<````C;JAZ]ENB<(Q\C':`?J)
MS<'%!0'JP<L"`X0DH````(VXH>O9;HGP,=@QR`'XB=7!Q04!Z,')`@.T)*0`
M``"-OJ'KV6Z)W3'-B>XQU@'^B<7!Q04![L'*`@.<)*@```"-NZ'KV6Z)RS'3
M,<,!^XGUP<4%`>O!R`(#C"2L````C;FAZ]ENB=$QP3'Q`?F)W<'%!0'IP<X"
M`Y0DL````(VZH>O9;HG",?(QV@'ZB<W!Q04!ZL'+`@.$)+0```"-N*'KV6Z)
M\#'8,<@!^(G5P<4%`>C!R0(#M"2X````C;ZAZ]ENB=TQS8GN,=8!_HG%P<4%
M`>[!R@(#G"2\````C;NAZ]ENB<LQTS'#`?N)]<'%!0'KP<@"`XPDP````(VY
MH>O9;HG1,<$Q\0'YB=W!Q04!Z<'.`@.4),0```"-NJ'KV6Z)PC'R,=H!^HG-
MP<4%`>K!RP(#A"3(````C;BAZ]ENB?`QV#'(`?B)U<'%!0'HP<D"B=T)S2'5
MB=\ASPGO`[0DS````('N)$/D<`'WB<7!Q04![\'*`HG-"=4AQ8G.(=8)[@.<
M)-````"!ZR1#Y'`!WHG[P<,%`=[!R`*)TPG#B=TA_8G3(<,)ZP.,)-0```"!
MZ21#Y'`!RXGQP<$%`<O!SP*)P0GYB<TA]8G!(?D)Z0.4)-@```"!ZB1#Y'`!
MT8G:P<(%`='!S@*)^@GRB=4AW8GZ(?()Z@.$)-P````M)$/D<`'"B<C!P`4!
MPL'+`HGU"=TAS8GP(=@)Z`.\).````"![R1#Y'`!^(G5P<4%`>C!R0*)W0G-
M(=6)WR'/">\#M"3D````@>XD0^1P`?Z)Q<'%!0'NP<H"B<T)U2'%B<\AUPGO
M`YPDZ````('K)$/D<`'[B?7!Q04!Z\'(`HG5"<4A]8G7(<<)[P.,).P```"!
MZ21#Y'`!^8G=P<4%`>G!S@*)Q0GU(=V)QR'W">\#E"3P````@>HD0^1P`?J)
MS<'%!0'JP<L"B?4)W2'-B?<AWPGO`X0D]````"TD0^1P`?B)U<'%!0'HP<D"
MB=T)S2'5B=\ASPGO`[0D^````('N)$/D<`'^B<7!Q04![L'*`HG-"=4AQ8G/
M(=<)[P.<)/P```"!ZR1#Y'`!^XGUP<4%`>O!R`*)U0G%(?6)UR''">\#C"0`
M`0``@>DD0^1P`?F)W<'%!0'IP<X"B<4)]2'=B<<A]PGO`Y0D!`$``('J)$/D
M<`'ZB<W!Q04!ZL'+`HGU"=TAS8GW(=\)[P.$)`@!```M)$/D<`'XB=7!Q04!
MZ,')`HG="<TAU8G?(<\)[P.T)`P!``"![B1#Y'`!_HG%P<4%`>[!R@*)S0G5
M(<6)SR'7">\#G"00`0``@>LD0^1P`?N)]<'%!0'KP<@"B=4)Q2'UB=<AQPGO
M`XPD%`$``('I)$/D<`'YB=W!Q04!Z<'.`HG%"?4AW8G'(?<)[P.4)!@!``"!
MZB1#Y'`!^HG-P<4%`>K!RP(#A"0<`0``+2H^G36)]3'=B>\QSP''B=#!P`4!
MQ\')`@.T)"`!``"![BH^G36)V#'(,=`!\(G]P<4%`>C!R@*)U@.<)"0!``"-
MD];!8LJ)RS'S,?L!TXG"P<(%`=/!SP(#C"0H`0``@>DJ/ITUB?(Q^C'"`<J)
MV<'!!0'*B<'!R0(#M"0L`0``C8;6P6+*B?TQS8GN,=X!QHG0P<`%`<;!RP(#
MO"0P`0``@>\J/ITUB<@QV#'0`?B)]<'%!0'HP<H"B=<#C"0T`0``C9'6P6+*
MB=DQ^3'Q`=&)PL'"!0'1P<X"`YPD.`$``('K*CZ=-8GZ,?(QP@':B<O!PP4!
MVHG#P<L"`[PD/`$``(V'UL%BRHGU,=V)[S'/`<>)T,'`!0''P<D"`[0D0`$`
M`('N*CZ=-8G8,<@QT`'PB?W!Q04!Z,'*`HG6`YPD1`$``(V3UL%BRHG+,?,Q
M^P'3B<+!P@4!T\'/`@.,)$@!``"!Z2H^G36)\C'Z,<(!RHG9P<$%`<J)P<')
M`@.T)$P!``"-AM;!8LJ)_3'-B>XQW@'&B=#!P`4!QL'+`@.\)%`!``"![RH^
MG36)R#'8,=`!^(GUP<4%`>C!R@(#C"14`0``@>DJ/ITUB=TQU8GO,?<!SXG!
MP<$%`<_!S@(#G"18`0``@>LJ/ITUB=$Q\3'!`=F)^\'#!0'9P<@"`Y0D7`$`
M`('J*CZ=-8GS,<,Q^P'3B<K!P@4!T\'/`@.T)&`!``"![BH^G36)PC'Z,<H!
M\HG=P<4%`>K!R0(#A"1D`0``C;#6P6+*B?@QR#'8`?")U<'%!0'HP<L"BW0D
M"`.T)&@!``"![BH^G34!]XG.,=XQU@'^B<7!Q04![HM\)`R)-XMT)!`!\(G^
MB4<$P<H"BVPD%(T$*HE'"(M\)!B-!!^)1@R+1"0<`<B)1A"+A"1L`0``92L%
M%````'4+@<1\`0``6UY?7</HL?#__U575E.#["R)5"0<A<`/A(D```")QJ$P
M,04(B40D&(7`='H/M@:$P'0$/#UU.3'MBWPD&(L?A=MT(XEL)`B)="0$B1PD
MZ`CQ__^%P'4&@#PK/70I@\<$BQ^%VW7=B=B#Q"Q;7E]=PXGQ@\$!#[8!A,!T
M!#P]=?(I\8G-Z[.)^HM$)!@IPL'Z`HM$)!R)$(U-`0'+B=B#Q"Q;7E]=PS';
MB=B#Q"Q;7E]=PU.![(@```")PV6A%````(E$)'PQP(U$)!R)1"0$B1PDZ!3P
M__^%P'4TBU0D+('B`/```('Z`$```'0(@?H`H```=1S'1"0$`@```(D<).AF
M[O__A<`/E,`/ML#K`C'`BU0D?&4K%10```!U"('$B````%O#Z)#O__]55U93
M@>R<````B<-EH10```")A"2,````,<"%VW0%@#L`=1^+A"2,````92L%%```
M``^%"@$``('$G````%M>7UW#B1PDZ!7N__^)QH7`=-.)-"3H9^[__X7`#X2G
M````C7@3@'@3+G4&@'\!`'3A@'@3+@^$HP```(D<).A.[O__B<6)/"3H1.[_
M_P'%@\4"B2PDZ-?N__^)Q8E\)!2)7"00QT0D#`C0!`C'1"0(_____\=$)`0!
M````B00DZ$WO__^-1"0LB40D!(DL).A][?__@_C_=!"+1"0\)0#P```]`$``
M`'1.B2PDZ/#M__^)+"3H..W__XDT).C`[?__A<`/A5G___^)-"3H(.[__XD<
M).B([O__Z0?___^`?P$N#X53____@'\"``^$(/___^E$____B>CHP_[__XUV
M`.NNZ$GN__]55U93@^P\B<>)TV6A%````(E$)"PQP(`Z/74#@\,!B1PDZ&+M
M__^)Q8U4)"B)^.AD_?__B<:%P`^$S@```(D$).A#[?__.>@/@ZP```"+5"0H
M`=(!T@^V!X3`#X1;`0``/#T/A%,!``")^(/``0^V"(3)=`6`^3UU\2GXB=:)
M5"04`S4P,04(@\4"`<6)+"3HE.W__XD&A<!T1J$P,04(BU0D%(L4$(U/`0^V
M!X@"/#UT&H3`=0;K%#P]=!"#P@&#P0$/MD'_B`*$P'7LQ@(],<`/M@P#B$P"
M`8/``83)=?&+1"0L92L%%`````^%W0```(/$/%M>7UW#,<`/MA0#B!0&@\`!
MA-)U\NO5BPTP,04(BS&%]@^$IP```#'VB?"#Q@&+%+&%TG7T@\`#`<`!P(L5
M8$$%"(72=5V)3"0<QP5@004(`0```(D$).C8[/__B40D%(7`=(B-%#8!THE4
M)`B)5"08BTPD'(E,)`2)!"3H(^W__XM$)!2C,#$%"(M4)!B+1"04QT2P!```
M``")="0HZ;[^__^)1"0$B0PDZ*7J__^)1"04HS`Q!0B%P`^$+/___XT4-@'2
MZ\<QP.FY_O__N`@````Q]NEB____Z'7L__]55U93@>PL$```B<:)UV6A%```
M`(F$)!P0```QP,=$)`C_#P``C6PD'(EL)`3'!"0.T`0(Z'SL__^%P'X0B<.-
M0/^`?!P;`'4YA<!U,XE\)`B)="0$H?`O!0AEBP")!"3H<.K__XN$)!P0``!E
M*P44````=4.!Q"P0``!;7E]=PXG#B5PD",=$)`0O````B2PDZ&_L__^%P'2S
MB5PD#(EL)`B)="0$H?`O!0AEBP")!"3H+^O__^NMZ+CK__]3@^PHQT0D#/C1
M!`C'1"0(T*$$",=$)`0=T`0(BQWP+P4(98L#B00DZ#OL___'1"04`````,=$
M)!"IT00(QT0D#*G1!`C'1"0(,LL$",=$)`0YT`0(98L#B00DZ&CJ__^#Q"A;
MPX/L',=$)`SXT00(QT0D"-"A!`C'1"0$'=`$"*'P+P4(98L`B00DZ-CK__^#
MQ!S#5U93@>PP(```9:$4````B80D+"```#'`Z'?H___'1"04&=`$"(E$)!#'
M1"0,3M`$",=$)`@!$```QT0D!`$```"-7"0JB1PDZ%?K___'1"0(`!```(VT
M)"L0``")="0$B1PDZ/SJ__^%P'A:B<.-0`&)!"3HB^K__X7`=!6)QX/[!',T
M]L,"=2;VPP%U'L8$&`"+E"0L(```92L5%````'4H@<0P(```6UY?PZ3KWV:E
M]L,!=-CK](G9P>D"\Z7VPP)TQ>OI,<#KR.A5ZO__Z2S___]55U93@>RL$```
MB[PDP!```(NT),00``!EH10```")A"2<$```,<"-;"0\B>JX7-`$".AH^?__
MB</'1"0$+P```(D\).@7Z/__A<!T+8GZN&70!`CHKOO__XGXBY0DG!```&4K
M%10````/A5(!``"!Q*P0``!;7E]=PXD\).@.Z?__B40D+,=$)`1RT`0(B30D
MZ-KI__^)QH7`=+&+1"0L@\`!B40D+(`^``^$Q````(7;=!2)="0$B1PDZ)#J
M__^%P`^$A0```(DT).C`Z/__@'P&_R]U#H/H`<8$!@"`?`;_+W3RBTPD+`'(
M/?\/```/CU?___^)?"08QT0D%'30!`B)="00QT0D#%_1!`C'1"0(`!```,=$
M)`0!````C;0DG````(DT).BCZ?__B6PD!(DT).C7Y___A<!U$(M$)$PE`/``
M`#T`@```=$?'1"0$<M`$",<$)`````#H#^G__XG&A<`/A.+^__^`/@`/A3S_
M__^%VW0%@#LN=`^^6M`$"+@!````Z5G___^`>P$`=+OKZ<=$)`0!````B30D
MZ%SG__^%P'6EB?*X9=`$".A3^O__B30DZ&3I___IFO[__^B*Z/__BT0D!`^V
M$(G!A-)T$(/``8#Z+P]$R`^V$(32=?")R,-3@^P8BUPD((7;#X2"````@#L`
M='V)'"3HC>?__X/H`0'8.<-R">L@@^@!.<-T=(`X+W3T.<-R"V:0ZPR#Z`$Y
MPW1@@#@O=?0YPW4'ZU6`."]U"8/H`3G#9I!R\BG8C5`"@?H`$```=U#'1"0,
M`!```(/``8E$)`B)7"0$QP0D8#$%".B2Y?__N&`Q!0B#Q!A;P\=$)"!:T`0(
M@\086^F7Z/__@#LO=.K'1"0@=-`$"(/$&%OI@>C__S'`@\086\-75H/L-&6A
M%````(E$)"PQP`^W!=31!`AFB40D"HU\)`R^UM$$"+@@````B<'!Z0+SI:@"
M=`)FI8U4)`2X=M`$".BS]O__A<!T)8M$)`0!P`'``P4P,04(BU`$B1"%TG37
M@\`$BU`$B1"%TG7TZ\F-5"0$N'_0!`CH?/;__X7`="6+1"0$`<`!P`,%,#$%
M"(M0!(D0A=)TUX/`!(M0!(D0A=)U].O)C50D!+B'T`0(Z$7V__^%P'0EBT0D
M!`'``<`#!3`Q!0B+4`2)$(72=->#P`2+4`2)$(72=?3KR8U4)`2XD-`$".@.
M]O__A<!T)8M$)`0!P`'``P4P,04(BU`$B1"%TG37@\`$BU`$B1"%TG7TZ\F-
M5"0$N)?0!`CHU_7__X7`="6+1"0$`<`!P`,%,#$%"(M0!(D0A=)TUX/`!(M0
M!(D0A=)U].O)C50D!+BGT`0(Z*#U__^%P'0EBT0D!`'``<`#!3`Q!0B+4`2)
M$(72=->#P`2+4`2)$(72=?3KR8U4)`2X7-`$".AI]?__A<!T)8M$)`0!P`'`
M`P4P,04(BU`$B1"%TG37@\`$BU`$B1"%TG7TZ\F-5"0$N+/0!`CH,O7__X7`
M="6+1"0$`<`!P`,%,#$%"(M0!(D0A=)TUX/`!(M0!(D0A=)U].O)C50D!+B]
MT`0(Z/OT__^%P'0EBT0D!`'``<`#!3`Q!0B+4`2)$(72=->#P`2+4`2)$(72
M=?3KR8U4)`2XQ]`$".C$]/__A<!T)8M$)`0!P`'``P4P,04(BU`$B1"%TG37
M@\`$BU`$B1"%TG7TZ\F-5"0$N&70!`CHC?3__X7`="6+1"0$`<`!P`,%,#$%
M"(M0!(D0A=)TUX/`!(M0!(D0A=)U].O)C50D!+C1T`0(Z%;T__^%P'0,B<*X
MO=`$".BN]O__C50D!+CBT`0(Z#CT__^%P'0,B<*X]-`$".B0]O__C50D!+C_
MT`0(Z!KT__^)PH7`="RX7-`$".AR]O__NBO1!`BXE]`$".AC]O__BT0D+&4K
M!10```!U4X/$-%Y?PXU4)`2X#]$$".C:\___A<!T#HG"N+/0!`CH,O;__^N^
M@7PD&U!!4E]UM(%\)!]#3$5!=:IF@7PD(TX]=:&-5"0EN+/0!`CH!?;__^N1
MZ$?D__^#[!QEH10```")1"0,H?PP!0B#^/]T$8M4)`QE*Q44````=3.#Q!S#
MC50D"+BST`0(Z&#S__^%P'09#[8`/#`/E<*$P`^5P`^VP"'0H_PP!0CKQ#'`
MZ_7HZ^/__X/L'.ACX___B00DZ#OC__^%P'0"BP"#Q!S#5U93@^PPBW0D0&6A
M%````(E$)"PQP(U4)"BXJ=$$".C\\O__A<!T!XG#@#@`=2.+1"0L92L%%```
M``^%FP```(GRN*G1!`B#Q#!;7E_I-O7__XET)`2)!"3H0^/__X7`=!2+1"0L
M92L%%````'5L@\0P6UY?PXDT).B3XO__B<>)'"3HB>+__P''@\<"B3PDZ!SC
M__^)QXE<)!C'1"04<M`$"(ET)!#'1"0,7]$$",=$)`C_____QT0D!`$```")
M!"3HBN/__XM$)"QE*P44````=0>)^NEG____C;8`````Z.OB__]55U93@>R<
M@0``B[PDL($``&6A%````(F$)(R!```QP,>$)+P````TT00(QX0DP````%K0
M!`C'A"3$`````````,>$)-@```#MT`0(QX0DW````#G1!`C'A"3@````"M$$
M",>$).0```!!T00(QX0DZ`````````#'A"3(````1=$$",>$),P```!*T00(
MQX0DT`````````"-5"1<N%S0!`CHD_'__X7`=`F`.``/A2\$``#HLN'__XD$
M).B*X?__A<`/A/,!``"+&(7;#X3I`0``B1PDZ%#A__\!P(/``8D$).CCX?__
MB<4/M@.)[H3`=#0/ML")1"00QT0D#%/1!`C'1"0(_____\=$)`0!````B2PD
MZ%'B__^#PP&#Q0(/M@.$P'7,C:PDV````+CTT`0(ZPJ#Q02+1?R%P'0LC50D
M7.CR\/__B<.%P'3G@#@`=.+HBO'__X7`D'38B1PDZ%;B__^)Q87`=2^-G"2\
M````BRN%[70B@'T```^$,P$``(GHZ%GQ__^%P`^%"@$``(/#!(LKA>UUWHDL
M).B)X/__B<.)-"3H?^#__P'#@<,$!```B1PDZ`_A__^)1"0TB70D',=$)!A8
MT00(QT0D%'30!`B);"00QT0D#%W1!`C'1"0(_____\=$)`0!````B<:)!"3H
M<>'__\=$)`3``0``B30DZ&'>__^#^/]U$.@WWO__BP"#^!$/A9`"``"-1"1<
MB40D!(M$)#2)!"3HZ.#__XG&A<!U%(M$)&PE`/```#T`0```#X3)````BT0D
M-(E$)!"+!XE$)`S'1"0(0-($",=$)`0!````H2`Q!0B)!"3H4][__S';BX0D
MC($``&4K!10````/A:H(``")V('$G($``%M>7UW#B2PDZ!CA__^)Q8/#!(7`
M#X3"_O__Z>7^__\Q[>G>_O__C;0DR````(L&A<!T&XU4)%SH:.___X7`=`6`
M.`!U*(/&!(L&A<!UY<<$)`T```#HV]___XG%B<:[+=$$"+A3````Z?#]__^)
M!"3HL.#__XG#A<!TRNF]_?__BVPD=.A,W___.<4/A2;___^+1"1L)?\!```]
MP`$```^%$O___XD<).B(W___B<.-5"1<N&;1!`CHY^[__X7`#X3"`0``B00D
MZ%C@__^)1"0$BP>)!"3H*O7__XG%A<`/A*(!``")+"3HJ-[__XG"@_@#=C7'
M1"0$:]$$"(U`_(E4)#@!Z(D$).A(X/__A<!U&(M4)#B#^@0/A/(%``"`?!7[
M+P^$YP4``*'\,`4(@_C_#X3+`P``A<`/A%D!``"Z*]$$"+BST`0(Z+[P___H
M<MS__\=$)!RIT00(B40D&,=$)!1TT`0(BWPD-(E\)!#'1"0,A-$$",=$)`C_
M____QT0D!`$```")'"3H1M___^M.Z!_<__^#.!%U68/&`>@BW/__QT0D(*G1
M!`B)="0<B40D&,=$)!1TT`0(B7PD$,=$)`R2T00(QT0D"/_____'1"0$`0``
M`(D<).CVWO__QT0D!,`!``")'"3HYMO__X/X_W2=BT0D-(D$).CUW/__B=JX
M7-`$".@`\/__B1PDZ'#Z___IR_W__XE$)!2+1"0TB40D$(L'B40D#,=$)`@$
MT@0(QT0D!`$```"A(#$%"(D$).CMV___Z97]__^)!"2)1"0TZ"OZ__^+E"2,
M@0``92L5%````(M$)#0/A3$&``")A"2P@0``@<2<@0``6UY?7>F>WO__BR_I
M5_[__\<%_#`%"`````#'1"0$`````(DL).A]V___B40D0(7`#X2+_O__QT0D
M#`(```#'1"0$[O___\=$)`C_____B<>)!"3H;][__\=$)`@&````C80DC`$`
M`(E$)`2)/"3HY-O__X"\)(P!````=0Z`O"2-`0``0P^$:@0``,=$)`P`````
MQT0D!`````#'1"0(`````(M$)$")!"3H&-[__\>$).P````!(T5GQX0D\```
M`(FKS>_'A"3T````_MRZF,>$)/@```!V5#(0QX0D_````/#ATL/'A"0``0``
M`````,>$)`0!````````QX0D2`$```````#'1"0X`````,=$)#P`````B5PD
M3,=$)`@`@```C80DC`$``(E$)`2+1"1`B00DZ!W;__^)Q87`#XZ3`0``C40M
M``'``<"+3"0\,=(!R`^2PHE$)#R#^@&#7"0X_XM,)#B)A"0``0``B>C!Z!T!
MP8E,)#B)C"0$`0``BY0D2`$``(VT)(P!``"%T@^%A@```(/]/WY6B?.-1<"-
M;D")PH/BP`'5B70D1(E$)$BY$````(V\)`@!``")WO.EC80D[````.@)X/__
M@\-`.>MUW8MT)$2+1"1(B<+!Z@:-2@'!X08!SL'B!BG0B<7'1"0,1````(EL
M)`B)="0$C80D"`$``(D$).@WVO__B:PD2`$``.G__O__OD`````IUCGNB?`/
M3\6-C"0(`0```=&)PHG/C;0DC`$``(/X!'-S]L("=`)FI8/B`70!I(N4)$@!
M```!PHF4)$@!``"#^D`/A/8!``"+A"0``0``B40D/(N$)`0!``")1"0XZ9?^
M__^-5"1<N+/0!`CHE.K__X7`#X1V_?__#[8`A,`/E<(\,`^5P`^VP"'0H_PP
M!0CI`_S___;!`0^%,@,``/?'`@````^%$@,``(G1P>D"\Z7I;/___XM<)$R+
M1"1`B00DZ*#:__^+1"0\P>@#@^`_C4@!QH0$"`$``("-A"0(`0``C3P(@_DX
M#XZ^`0``ND`````IRG0C,<#VP@%T#,8'`+@!````.=!S$,8$!P#&1`<!`(/`
M`CG0<O"-A"3L````Z)#>__^Y#@```#'`C;PD"`$``/.KBT0D.`_(B80D0`$`
M`(M$)#P/R(F$)$0!``"-A"3L````Z%K>__^+A"3L````#\B)A"1/`0``BX0D
M\`````_(B80D4P$``(N$)/0````/R(F$)%<!``"+A"3X````#\B)A"1;`0``
MBX0D_`````_(B80D7P$``(VL)$\!``"-O"1C`0``B?X/MD4`B40D$,=$)`Q3
MT00(QT0D"/_____'1"0$`0```(D\).A2VO__@\4!@\<".?5USL:$)(L!````
MQT0D'*G1!`B-A"1C`0``B40D&,=$)!1TT`0(BT0D-(E$)!#'1"0,==$$",=$
M)`C_____QT0D!`$```")'"3H_=G__^D7^___*<6-C"2,`0``C30!C80D[```
M`.A@W?__BX0D``$``(E$)#R+A"0$`0``B40D..D$_?__BW\$A?\/A`[Z__^)
M/"3H<MC__X/X`P^&_?G__\=$)`1PT00(@^@$`?B)!"3H%-K__X7`#T3OZ=[Y
M__^Z.````"G*,<"#^@0/@Z$```#VP@)T`F:K@^(!#X1H_O__JNEB_O__@+PD
MC@$``$$/A8C[__^`O"2/`0``0P^%>OO__X"\))`!``!(#X5L^___@+PDD0$`
M`$4/A5[[___'1"0,`@```,=$)`3&____QT0D"/____^+?"1`B3PDZ';9___'
M1"0(*0```(V$)(P!``")1"0$B3PDZ.O6___'1"0<J=$$"(V$)(P!``#IIO[_
M__?'`0````^%CP```/?'`@```'5]@_H$#X)"____B=6#Y?R-3?_!Z0*#X0&)
MSHD'N00````YZ7,>A?9T#(E'!+D(````.>ES#HD$#XE$#P2#P0@YZ7+R`<_I
M`O___P^W#F:)#X/'`H/&`H/J`NG:_/__#[:4)(P!``"(5"0XB!&#QP&-M"2-
M`0``C5#_Z:[\__]FJX/J`NEY____JH/J`>EH____Z*[7__]55U93@^P\9:$4
M````B40D+#'`BS7P+P4(98L>#[9#9(A#98U4)"BXE]`$".C,YO__A<!T"8`X
M,0^$>0(``.C![___98L>QT0D#`L```#'1"0(`0```,=$)`2CT00(B1PDZ)C5
M__^%P`^$00(``(M`#(M`&(E$)!QEBRZ#/6A!!0@!#XZ:````,=OK2L=$)`P"
M````QT0D"`````")5"0$B2PDZ";8__]EBRZ)1"0$C7L!H61!!0B+!+B)!"3H
M[-?__XG!H6A!!0B%R75*@\,".=B)^WY!QT0D#`````")7"0(BT0D'(E$)`2)
M+"3H3-;__X7`=!F+$&6++HM"""4`!"``/0`$``!U@HM"#.N<H6A!!0AEBRZ-
M4/\YTP^$-`$``,=$)`P#````QT0D"`$```#'1"0$J-$$"(DL).B\U/__B<.%
MP'0KQT0D"*K1!`B+0`R+`(E$)`1EBP:)!"3HJM3__XM##(L`]D`*0`^%:0$`
M`,=$)`P#````QT0D"`$```#'1"0$K]$$"&6+!HD$).AHU/__B<.%P'0NC50D
M*+AET`0(Z%/E__^%P`^$%`$``(E$)`B+0PR+`(E$)`1EBP:)!"3H1-3__\=$
M)`@!````QT0D!+'1!`AEBP:)!"3H:=/__\=$)`C&T00(B40D!&6+!HD$).@2
MU/__98L&QD!E`(U4)"BX7-`$".CLY/__B<.C;$$%"(7`=&O'1"0$P`$``(D<
M).@"T___C5`!@_H!=@F#^!$/A;@```"+1"0L92L%%`````^%H@```(/$/%M>
M7UW#@_@!#X[#_O__NP$```"+1"0<B40D!(DL).AZT___@\,!98LN.1UH004(
M?^+IF_[__Z%D004(B00DZ"_R__^)PZ-L004(A<`/A7G____'!"24T@0(Z%_5
M__]EBR[I:_[__X!X`0`/A(7]___I>/W__Z%D004(BQ"+0PR+`.ABZ/__Z>[^
M__^)1"0$98L&B00DZ+/4___I@_[__^BYU/__B40D#(E<)`BA9$$%"(L`B40D
M!,<$)+C2!`CH^M3__U=64X/L((MT)#!EH10```")1"0<,<")-"3H$NS__P^V
M$(G#A-)T$(/``8#Z+P]$V`^V$(32=?"A_#`%"(7V#Y7!B<^#^/]T7H7`#Y7"
M(?J$TG48BT0D'&4K!10````/A80```"#Q"!;7E_#@#X`=./'1"0(!````,=$
M)`18T00(B1PDZ++4__^%P'7'BT0D'&4K!10```!U3XGP@\0@6UY?Z63D__^-
M5"08N+/0!`CH->/__X7`="$/MA"`^C`/E<"$T@^5PB'0B?HAP@^VP*/\,`4(
MZ7;____'!?PP!0@`````Z6O____HK=/___,/'OM3@^P8Z!#7__^!P[1@``"+
M@P0!``")1"0,BT0D*(E$)`B+1"0DB40D!(M$)"")!"3HE-'__X/$&%O#````
M\P\>^U.#[`CHS];__X'#<V```(/$"%O#````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````#`````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E
M:2\E<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$52
M3$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?
M1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,
M7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`4UE35$5-`"]T
M;7``5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X`'!A<BT`)7,E<R5S
M)7,`4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E
M<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z
M.E9%4E-)3TX`,2XP-#4`+64`+2T```!?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@(`````!P97)L>'-I+F,````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M
M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!5;F%B;&4@=&\@
M8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")]
M)PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G
M92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE
M.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z
M.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E
M;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R
M;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`[
M"FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D
M=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L
M"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&
M1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A
M+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@
M)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N
M86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@
M,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P
M87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@
M*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z
M.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM0
M05)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/
M(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>
M3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY
M("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).
M7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S
M=#L*8FEN;6]D92A?1D@I.PIM>2`D8G5F.PIM>2`D<VEZ92`]("US("1P<F]G
M;F%M93L*;7D@)&]F9G-E="`](#4Q,CL*;7D@)&ED>"`]("TQ.PIW:&EL92`H
M,2D*>PHD;V9F<V5T(#T@)'-I>F4@:68@)&]F9G-E="`^("1S:7IE.PIS965K
M(%]&2"P@+21O9F9S970L(#(@;W(@9&EE('%Q6W-E96L@9F%I;&5D(&]N("(D
M<')O9VYA;64B.B`D(5T["FUY("1N<F5A9"`](')E860@7T9(+"`D8G5F+"`D
M;V9F<V5T.PID:64@<7%;<F5A9"!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M72!U;FQE<W,@)&YR96%D(#T]("1O9F9S970["B1I9'@@/2!R:6YD97@H)&)U
M9BP@(EQN4$%2+G!M7&XB*3L*;&%S="!I9B`D:61X(#X](#`@?'P@)&]F9G-E
M="`]/2`D<VEZ92!\?"`D;V9F<V5T(#X@,3(X("H@,3`R-#L*)&]F9G-E="`J
M/2`R.PI]"FQA<W0@=6YL97-S("1I9'@@/CT@,#L*)&]F9G-E="`M/2`D:61X
M("T@-#L*<V5E:R!?1D@L("TD;V9F<V5T+"`R.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<V5E:R!?1D@L("TD;V9F<V5T("T@=6YP86-K*").(BP@)&)U9BDL(#([
M"G)E860@7T9(+"`D8G5F+"`T.PHD9&%T85]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L*;7D@)7)E<75I<F5?;&ES=#L*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W1E
M;7!F:6QE*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ
M1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H
M("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&)A<V5N
M86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE
M7&XB*3L*?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)%!!
M4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D
M8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A
M9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E
M;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PIM>2`D:V5Y.PIF;W)E86-H("AK97ES("5R97%U
M:7)E7VQI<W0I('L*;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\["B1K97D@
M/2`D7SL@;&%S=#L*?0ID96QE=&4@)')E<75I<F5?;&ES='LD:V5Y?2!I9B!D
M969I;F5D*"1K97DI.PI](&]R(')E='5R;CL*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.
M?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PIP
M<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*<V5E:R@D9F@L(#`L(#`I.PIR
M971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H
M(B1F:6QE;F%M92T^>V-R8WTN<&TB+"`D9FEL96YA;64M/GMB=69]*3L*;W!E
M;B!M>2`D9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D
M9FEL96YA;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PI]+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z
M.DAE879Y.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U
M:7)E($E/.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y
M<R`E<F5Q=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]
M?B`O7"YP;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID
M;R`D9FEL96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ
M95PN<&PD+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T[
M"GT*;&%S="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P
M;W,@/2`H=&5L;"!?1D@I("T@-#L*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[
M4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E
M8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%3E9[4$%27T1%
M0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF
M("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'
M5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.
M5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z
M.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF
M="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER
M92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PI!
M<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@Q,C@J,3`R-"D["F]P96X@;7D@
M)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A
M(CL*8FEN;6]D92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R![
M"FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!
M+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S
M+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]
M"GT["FQO8V%L("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!0
M05(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I
M.PID:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E
M<2`B4$M<,#`S7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]
M($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)
M3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W
M-S<L"BD@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@
M)&1A=&%?<&]S*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?
M5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E]
M(&]R(&YE>'0["B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO
M.PIM>2`D;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R([
M"FUY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D
M97(@/7X@<WLD;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H
M;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT
M*"1L;V%D97(I.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIM>2`E9FEL
M97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O
M8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#
M;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E86-H("AS;W)T(&ME
M>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF;W)E86-H(&UY("1D
M:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA;64I(#T@*"0Q+"`D
M,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI
M7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE
M>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I
M<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H
M)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+SL*;W5T<R@@
M:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN
M86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N=&5N=#L*:68@*')E
M9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92![
M"F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I
M;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@/2`\1DE,13X["F-L
M;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D
M;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D["B1F:"T^<')I;G0H
M(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K
M(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E<R(L($%R8VAI=F4Z
M.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64**2D["B1F:"T^
M<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*)&9H+3YP<FEN
M="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I
M(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P
M+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H
M)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E
M($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@
M<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D
M<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@
M?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S
M:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@:68@
M*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC
M;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X](")<,"(@>"`H-#$@
M+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M92`N/2`B0T%#2$4B
M.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D["B1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E;BAF:6QE;F\H7T9(
M*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*
M)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["B1Q=6EE="`]("$D
M14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@(B1%
M3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@
M>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C:"!M>2`D
M;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M8F5R+3YI
M<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_<VAL:6(O
M"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH/SHD0V]N9FEG.CI#
M;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?
M;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL
M92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S
M=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I
M*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@
M86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D["GT@96QS92!["F]U
M=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M
M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I
M.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PI]
M"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PID
M:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@+4%L:6(N<&%R
M(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@72!;('!R;V=R
M86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B1%
M3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P(#T@<VAI9G0H0$%2
M1U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE*2`]($!?.PIR97%U
M:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X
M="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG
M*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T:#HZ;6MP871H*"1P
M871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D:65S('=I=&@@97)R
M;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER92!L:6(["G)E<75I
M<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR97%U:7)E('-T<FEC
M=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S.PIR97%U:7)E($-A
M<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17)R;F\["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.PIR97%U:7)E
M($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ4W!E
M8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF:6<["G)E<75I<F4@
M24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!#;VUP<F5S
M<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@4$%2.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U
M:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ
M56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M
M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!0
M97)L24\Z.G-C86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B
M(%]S971?<&%R7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A
M;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q
M.PIR971U<FX["GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL
M('%W*"!005)?5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ
M=R@@0SI<7%1%35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@
M)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE
M.PIM>2`D<'=U:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF
M(&1E9FEN960@)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE
M*2`I('L*)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@
M*&1E9FEN960@)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E
M('L*)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\
M?"`G4UE35$5-)SL*?0HD=7-E<FYA;64@/7X@<R]<5R]?+V<["FUY("1S=&UP
M9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L
M("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PII9B`H(21%3E9[
M4$%27T-,14%.?2!A;F0@;7D@)&UT:6UE(#T@*'-T870H)'!R;V=N86UE*2E;
M.5TI('L*;W!E;B`H;7D@)&9H+"`B/"(N("1P<F]G;F%M92D["G-E96L@)&9H
M+"`M,3@L(#(["G-Y<W)E860@)&9H+"!M>2`D8G5F+"`V.PII9B`H)&)U9B!E
M<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<WES<F5A9"`D9F@L
M("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D0V]N
M9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*?0IE;'-E('L*;7D@)&-T>"`]
M(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W
M*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z
M.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$
M:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D
M1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S:6]N
M(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C='@M
M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*
M:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1P<F]G;F%M92(I*2!["F)I
M;FUO9&4H)&9H*3L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]
M"GT*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C
M='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@*3L*?0IC;&]S92@D9F@I
M.PI]"F5L<V4@>PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B
M)$-O;F9I9WM?9&5L:6U]=&5M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D
M<W1M<&1I<CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T
M96UP(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!]
M(#U^("\H+BLI+SL*?0IS=6(@7W1E;7!F:6QE('L*;7D@*"1N86UE+"`D8V]N
M=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T96UP
M+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N86UE
M(#T@(B1F=6QL;F%M92XD)"(["F]P96X@;7D@)&9H+"`G/B<L("1T96UP;F%M
M92!O<B!D:64@(F-A;B=T('=R:71E("1T96UP;F%M93H@)"$B.PIB:6YM;V1E
M("1F:#L*<')I;G0@)&9H("1C;VYT96YT<SL*8VQO<V4@)&9H.PIC:&UO9"`D
M;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M
M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T
M=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I
M;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345]
M(#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]
M("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@
M)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P
M<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K
M(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["FEF("AO<&5N(&UY("1F
M:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F:#L*?0II9B`H
M+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B1P<F]G;F%M92`N/2`D
M0V]N9FEG>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@*'-P
M;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI;7U<120O+SL*
M*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G
M;F%M92!["B0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T[
M"FEF("AI;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2![
M"B1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM
M>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D
M*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W
M9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_
M/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM
M?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A
M<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!3$E:141]*RL@/3T@
M,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])3DE424%,25I%1'T@
M/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(
M12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PID96QE=&4@)$5.5GLG4$%2
M7R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I
M('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I
M9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L
M96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*:68@
M*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*
M96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D
M=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.
M(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@/7X@+UY005)?
M0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T
M.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92![
M"G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N
M9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O
M;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE
M>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]
M"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"90
M05(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7$H
M<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.
M;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA
M;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)2
M3U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I
M9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@`!&P,[T````!D`````D?__%`$`
M`."4__]X!0``X);__^P````:E___``$``+"7__\X`0``_Z+__WP!``"GH___
MY`$``""D__\,`@``9Z7__TP"```[I___C`(``/BG___,`@``7:C___`"``",
MJ/__"`,``%NI__]``P``8*G__U0#```FJ___E`,``$:K__^H`P``!JS__^@#
M``!IK___&`0``,6O__\T!```WZ___TP$``#%L/__E`0```*\___P!```%K__
M_S`%```#P/__J`4``!0``````````7I2``%\"`$;#`0$B`$``!`````<````
M[)7__SH`````1`<($````#`````2EO__!0`````````@````1````.2/___@
M`P````X(1@X,2@\+=`1X`#\:.RHR)")`````:````'"6__]/"P```$$."(4"
M00X,AP-!#A"&!$$.%(,%1@Z0`P,["PH.%$'##A!!Q@X,0<<."$'%#@1!"P``
M`&0```"L````>Z'__Z@`````00X(A0)!#@R'`T$.$(8$00X4@P5##D`"6@H.
M%$'##A!!Q@X,0<<."$'%#@1!"W$*#A1!PPX00<8.#$''#@A!Q0X$00M'#A1!
MPPX00<8.#$''#@A!Q0X$)````!0!``"[H?__>0````!!#@B#`D8.D`$":PH.
M"$'##@1!"P```#P````\`0``#*+__T<!````00X(A0)!#@R'`T$.$(8$00X4
M@P5&#K`!=`H.%$'##A!!Q@X,0<<."$'%#@1!"P`\````?`$``!.C___4`0``
M`$$."(4"00X,AP-!#A"&!$$.%(,%0PY0`NX*#A1!PPX00<8.#$''#@A!Q0X$
M00L`/````+P!``"GI/__O0````!!#@B%`D$.#(<#00X0A@1!#A2#!48.P"`"
M<0H.%$'##A!!Q@X,0<<."$'%#@1!"R````#\`0``)*7__V4`````00X(@P)#
M#C`"7PX(0<,.!````!0````@`@``9:7__R\`````0PX@:PX$`#0````X`@``
M?*7__\\`````00X(AP)!#@R&`T$.$(,$1@[`0`*?"@X00<,.#$'&#@A!QPX$
M00L`$````'`"```3IO__!0`````````\````A`(```2F___&`0```$$."(4"
M00X,AP-!#A"&!$$.%(,%1@[`(0)K"@X40<,.$$'&#@Q!QPX(0<4.!$$+$```
M`,0"``"*I___(``````````\````V`(``):G___``````$$."(,"0PX@`HP*
M#@A!PPX$00M+"@X(0<,.!$4+4`H."$'##@1%"T4."$'##@0`+````!@#```6
MJ/__8P,```!!#@B'`D$.#(8#0PY``PD#"@X,0<8."$''#@1!"P``&````$@#
M``!)J___7`````!##B!D"@X$00L``!0```!D`P``B:O__QH`````0PX@5@X$
M`$0```!\`P``BZO__^8`````00X(AP)!#@R&`T$.$(,$0PY``D0*#A!!PPX,
M0<8."$''#@1%"V`*#A!!PPX,0<8."$''#@1!"U@```#$`P``*:S__ST+````
M00X(A0)!#@R'`T$.$(8$00X4@P5&#K"#`@.,`@H.%$'##A!!Q@X,0<<."$'%
M#@1!"P-Y`@H.%$'##A!!Q@X,0<<."$'%#@1%"P``/````"`$```*M___%`,`
M``!!#@B%`D$.#(<#00X0A@1!#A2#!4,.4`-*`@H.%$'##A!!Q@X,0<<."$'%
M#@1!"T0```!@!```WKG__^T`````00X(AP)!#@R&`T$.$(,$0PXP`F$*#A!!
MPPX,0<8."$''#@1!"W,*#A!!PPX,0<8."$''#@1%"RP```"H!```8(____T!
M````00X(A0)"#05)AP.&!(,%`UH!"L-!QD''0<4,!`1!"QP```#8!```4[K_
M_SX`````10X(@P)##B!T#@A!PPX$````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````-:F!`BVI@0(```````````````````````````!````
MY@(```$```#X`@```0````(#```!````#`,```\```!R!```#`````"@!`@-
M````=,\$"!D```#(+@4(&P````0````:````S"X%"!P````$````]?[_;S2"
M!`@%````Y(@$"`8````D@P0("@```*D$```+````$````!4``````````P``
M`/0O!0@"````Z`$``!0````1````%P````B/!`@1````V(X$"!(````P````
M$P````@```#^__]O2(X$"/___V\!````\/__;XZ-!`@`````````````````
M`````````````````````````````````````````````````````````.0N
M!0@``````````$:@!`A6H`0(9J`$"':@!`B&H`0(EJ`$"*:@!`BVH`0(QJ`$
M"-:@!`CFH`0(]J`$"`:A!`@6H00()J$$"#:A!`A&H00(5J$$"&:A!`AVH00(
MAJ$$"):A!`BFH00(MJ$$",:A!`C6H00(YJ$$"/:A!`@&H@0(%J($"":B!`@V
MH@0(1J($"%:B!`AFH@0(=J($"(:B!`B6H@0(IJ($"+:B!`C&H@0(UJ($".:B
M!`CVH@0(!J,$"!:C!`@FHP0(-J,$"$:C!`A6HP0(9J,$"':C!`B&HP0(EJ,$
M"*:C!`BVHP0(QJ,$"-:C!`CFHP0(]J,$"`:D!`@``````````/_____\T@0(
M1T-#.B`H4$Q$+4QI;G5X*2`Q,RXQ+C`@,C`R,S`V,C<@*')E;&5A<V4I```N
M<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N8G5I;&0M:60`+FYO=&4N9VYU
M+G!R;W!E<G1Y`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`+F1Y
M;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`+G)E
M;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN
M<F\`+F1Y;F%M:6,`+F=O=``N9V]T+G!L=``N9&%T80`N8G-S`"YC;VUM96YT
M```````````````````````````````````````````````````````+````
M`0````(```"T@00(M`$``!,```````````````$`````````$P````<````"
M````R($$",@!```D```````````````$`````````"8````'`````@```.R!
M!`CL`0``*```````````````!``````````Y````!P````(````4@@0(%`(`
M`"````````````````0`````````1P```/;__V\"````-(($"#0"``#P````
M!@`````````$````!````%$````+`````@```"2#!`@D`P``P`4```<````!
M````!````!````!9`````P````(```#DB`0(Y`@``*D$``````````````$`
M````````80```/___V\"````CHT$"(X-``"X````!@`````````"`````@``
M`&X```#^__]O`@```$B.!`A(#@``D`````<````!````!`````````!]````
M"0````(```#8C@0(V`X``#`````&``````````0````(````A@````D```!"
M````"(\$"`@/``#H`0``!@```!@````$````"````(\````!````!@````"@
M!`@`(```)```````````````!`````````"*`````0````8````PH`0(,"``
M`.`#`````````````!`````$````E0````$````&````$*0$"!`D``!A*P``
M```````````0`````````)L````!````!@```'3/!`AT3P``&```````````
M````!`````````"A`````0````(`````T`0(`%```#`_``````````````0`
M````````J0````$````"````,`\%"#"/``#4```````````````$````````
M`+<````!`````@````00!0@$D```^`0`````````````!`````````#!````
M#@````,```#(+@4(R)X```0```````````````0````$````S0````\````#
M````S"X%",R>```$```````````````$````!````-D````!`````P```-`N
M!0C0G@``$P``````````````!`````````#F````!@````,```#D+@4(Y)X`
M``@!```'``````````0````(````[P````$````#````["\%".R?```(````
M```````````$````!````/0````!`````P```/0O!0CTGP````$`````````
M````!`````0```#]`````0````,```#T,`4(]*```!````````````````0`
M`````````P$```@````#````(#$%"`2A``!4$``````````````@````````
M``@!```!````,``````````$H0``*P```````````````0````$````!````
D`P``````````````+Z$``!$!``````````````$`````````
